% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sample_size_calculate.R
\name{icc_sample_size_lower}
\alias{icc_sample_size_lower}
\title{Sample Size for ICC based on Lower Confidence Limit}
\usage{
icc_sample_size_lower(
  rho,
  rho0 = NULL,
  k = 3,
  same_raters,
  rater_effect = NULL,
  rating_type,
  agreement_type = NULL,
  alpha = 0.05,
  assurance = 0.8,
  rating_target = NULL,
  verbose = TRUE
)
}
\arguments{
\item{rho}{Anticipated ICC value.}

\item{rho0}{Desired lower bound.}

\item{k}{Number of observations per subject. Default 3.}

\item{same_raters}{Logical.}

\item{rater_effect}{"random" or "fixed".}

\item{rating_type}{"single" or "average".}

\item{agreement_type}{"absolute" or "consistency".}

\item{alpha}{Significance level. Default 0.05.}

\item{assurance}{Assurance probability. Default 0.8.}

\item{rating_target}{Shortcut for rho0.}

\item{verbose}{Print messages. Default TRUE.}
}
\value{
Required sample size.
}
\description{
Sample Size for ICC based on Lower Confidence Limit
}
\examples{
# Note: It is recommended to use the unified interface icc_sample_size()
icc_sample_size_lower(rho = 0.8, rho0 = 0.6, k = 3, same_raters = FALSE, rating_type = "single")
}
