% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sample_size_calculate.R
\name{icc_power}
\alias{icc_power}
\title{Power Calculation for ICC Study Design}
\usage{
icc_power(
  n,
  rho,
  rho0 = NULL,
  omega = NULL,
  k = 3,
  same_raters,
  rater_effect = NULL,
  rating_type,
  agreement_type = NULL,
  alpha = 0.05,
  method = c("lower", "width"),
  verbose = TRUE
)
}
\arguments{
\item{n}{Number of subjects.}

\item{rho}{Anticipated ICC value.}

\item{rho0}{Lower bound for method="lower".}

\item{omega}{Half-width for method="width".}

\item{k}{Number of observations. Default 3.}

\item{same_raters}{Logical.}

\item{rater_effect}{"random" or "fixed".}

\item{rating_type}{"single" or "average".}

\item{agreement_type}{"absolute" or "consistency".}

\item{alpha}{Significance level. Default 0.05.}

\item{method}{"lower" or "width".}

\item{verbose}{Print messages. Default TRUE.}
}
\value{
Power.
}
\description{
Power Calculation for ICC Study Design
}
\examples{
# Note: It is recommended to use the unified interface icc_sample_size()
icc_power(n = 30, rho = 0.7, rho0 = 0.5, k = 3,
          same_raters = TRUE, rater_effect = "fixed",
          rating_type = "single", agreement_type = "consistency")
}
